==> deepin-system-monitor_6.0.7.tar.xz: BUILD/deepin-system-monitor-plugin-popup/translations/deepin-system-monitor-plugin-popup_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="130"/>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
</context>
<context>
    <name>Cpu.Widget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="180"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CpuWidget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="216"/>
        <location filename="../gui/cpu_widget.cpp" line="217"/>
        <source>Utilization</source>
        <translation>Nutzung</translation>
    </message>
</context>
<context>
    <name>Disk.Widget</name>
    <message>
        <location filename="../gui/disk_widget.cpp" line="228"/>
        <source>Disk</source>
        <translation>Datenträger</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="258"/>
        <source>Read</source>
        <translation>Lesen</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="259"/>
        <source>Write</source>
        <translation>Schreiben</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="42"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="48"/>
        <source>Display shortcuts</source>
        <translation>Tastenkombinationen anzeigen</translation>
    </message>
</context>
<context>
    <name>Memory.Widget</name>
    <message>
        <location filename="../gui/memory_widget.cpp" line="152"/>
        <source>Memory</source>
        <translation>Arbeitsspeicher</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="179"/>
        <location filename="../gui/memory_widget.cpp" line="188"/>
        <source>Swap</source>
        <translation>Auslagerung</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="180"/>
        <source>Not enabled</source>
        <translation>Nicht aktiviert</translation>
    </message>
</context>
<context>
    <name>Net.Widget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="259"/>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="260"/>
        <source>Total received</source>
        <translation>Insgesamt empfangen</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="262"/>
        <source>Total sent</source>
        <translation>Insgesamt gesendet</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="261"/>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
</context>
<context>
    <name>NetWidget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="232"/>
        <location filename="../gui/net_widget.cpp" line="235"/>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../process/process.cpp" line="67"/>
        <source>Very high</source>
        <translation>Sehr hoch</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="68"/>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="69"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="70"/>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="71"/>
        <source>Very low</source>
        <translation>Sehr niedrig</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="72"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="73"/>
        <source>Invalid</source>
        <translation>Ungültig</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="162"/>
        <source>Failed to end process</source>
        <translation>Prozess beenden ist fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="165"/>
        <source>Failed to pause process</source>
        <translation>Prozess pausieren ist fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="168"/>
        <source>Failed to resume process</source>
        <translation>Prozess fortsetzen ist fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="171"/>
        <source>Failed to kill process</source>
        <translation>Prozess beenden ist fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="174"/>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="224"/>
        <source>Failed in sending signal to process</source>
        <translation>Senden eines Signals an den Prozess fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="175"/>
        <source>No response</source>
        <translation>Keine Rückmeldung</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="180"/>
        <source>Suspend</source>
        <translation>Anhalten</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="96"/>
        <location filename="../process/process_name.cpp" line="103"/>
        <location filename="../process/process_name.cpp" line="106"/>
        <source>Tray</source>
        <translation>Benachrichtigungsfeld</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="76"/>
        <source>End process</source>
        <translation>Prozess beenden</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="82"/>
        <source>Suspend process</source>
        <translation>Prozess anhalten</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="88"/>
        <source>Resume process</source>
        <translation>Prozess fortsetzen</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="93"/>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="99"/>
        <source>Kill process</source>
        <translation>Prozess abwürgen</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="31"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="33"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="35"/>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="37"/>
        <source>Memory</source>
        <translation>Arbeitsspeicher</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Shared memory</source>
        <translation>Gemeinsamer Speicher</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="39"/>
        <source>Virtual memory</source>
        <translation>Virtueller Speicher</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="41"/>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="43"/>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="45"/>
        <source>Disk read</source>
        <translation>Datenträger lesen</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="47"/>
        <source>Disk write</source>
        <translation>Datenträger schreiben</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="49"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="51"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="53"/>
        <source>Priority</source>
        <translation>Priorität</translation>
    </message>
</context>
<context>
    <name>ProcessWidget</name>
    <message>
        <location filename="../gui/process_widget.cpp" line="65"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="72"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="182"/>
        <location filename="../gui/process_widget.cpp" line="185"/>
        <source>Processes</source>
        <translation>Prozesse</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="267"/>
        <source>Not support</source>
        <translation>Nicht unterstützt</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="123"/>
        <source>Restart</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="128"/>
        <source>Refresh</source>
        <translation>Aktualisieren</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="69"/>
        <source>Force end application</source>
        <translation>Beenden des Programms erzwingen</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="54"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="63"/>
        <source>Processes</source>
        <translation>Prozesse</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <source>Services</source>
        <translation>Dienste</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_6.5.12.tar.xz: BUILD/deepin-system-monitor-plugin-popup/translations/deepin-system-monitor-plugin-popup_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="130"/>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
</context>
<context>
    <name>Cpu.Widget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="180"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CpuWidget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="216"/>
        <location filename="../gui/cpu_widget.cpp" line="217"/>
        <source>Utilization</source>
        <translation>Nutzung</translation>
    </message>
</context>
<context>
    <name>Disk.Widget</name>
    <message>
        <location filename="../gui/disk_widget.cpp" line="228"/>
        <source>Disk</source>
        <translation>Datenträger</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="258"/>
        <source>Read</source>
        <translation>Lesen</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="259"/>
        <source>Write</source>
        <translation>Schreiben</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="42"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="48"/>
        <source>Display shortcuts</source>
        <translation>Tastenkombinationen anzeigen</translation>
    </message>
</context>
<context>
    <name>Memory.Widget</name>
    <message>
        <location filename="../gui/memory_widget.cpp" line="152"/>
        <source>Memory</source>
        <translation>Arbeitsspeicher</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="179"/>
        <location filename="../gui/memory_widget.cpp" line="188"/>
        <source>Swap</source>
        <translation>Auslagerung</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="180"/>
        <source>Not enabled</source>
        <translation>Nicht aktiviert</translation>
    </message>
</context>
<context>
    <name>Net.Widget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="259"/>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="260"/>
        <source>Total received</source>
        <translation>Insgesamt empfangen</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="262"/>
        <source>Total sent</source>
        <translation>Insgesamt gesendet</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="261"/>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
</context>
<context>
    <name>NetWidget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="232"/>
        <location filename="../gui/net_widget.cpp" line="235"/>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../process/process.cpp" line="67"/>
        <source>Very high</source>
        <translation>Sehr hoch</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="68"/>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="69"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="70"/>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="71"/>
        <source>Very low</source>
        <translation>Sehr niedrig</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="72"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="73"/>
        <source>Invalid</source>
        <translation>Ungültig</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="162"/>
        <source>Failed to end process</source>
        <translation>Prozess beenden ist fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="165"/>
        <source>Failed to pause process</source>
        <translation>Prozess pausieren ist fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="168"/>
        <source>Failed to resume process</source>
        <translation>Prozess fortsetzen ist fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="171"/>
        <source>Failed to kill process</source>
        <translation>Prozess beenden ist fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="174"/>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="224"/>
        <source>Failed in sending signal to process</source>
        <translation>Senden eines Signals an den Prozess fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="175"/>
        <source>No response</source>
        <translation>Keine Rückmeldung</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="180"/>
        <source>Suspend</source>
        <translation>Anhalten</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="96"/>
        <location filename="../process/process_name.cpp" line="103"/>
        <location filename="../process/process_name.cpp" line="106"/>
        <source>Tray</source>
        <translation>Infobereich</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="76"/>
        <source>End process</source>
        <translation>Prozess beenden</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="82"/>
        <source>Suspend process</source>
        <translation>Prozess anhalten</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="88"/>
        <source>Resume process</source>
        <translation>Prozess fortsetzen</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="93"/>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="99"/>
        <source>Kill process</source>
        <translation>Prozess abwürgen</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="31"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="33"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="35"/>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="37"/>
        <source>Memory</source>
        <translation>Arbeitsspeicher</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Shared memory</source>
        <translation>Gemeinsamer Speicher</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="39"/>
        <source>Virtual memory</source>
        <translation>Virtueller Speicher</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="41"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="43"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="45"/>
        <source>Disk read</source>
        <translation>Datenträger lesen</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="47"/>
        <source>Disk write</source>
        <translation>Datenträger schreiben</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="49"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="51"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="53"/>
        <source>Priority</source>
        <translation>Priorität</translation>
    </message>
</context>
<context>
    <name>ProcessWidget</name>
    <message>
        <location filename="../gui/process_widget.cpp" line="65"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="72"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="182"/>
        <location filename="../gui/process_widget.cpp" line="185"/>
        <source>Processes</source>
        <translation>Prozesse</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="267"/>
        <source>Not support</source>
        <translation>Nicht unterstützt</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="123"/>
        <source>Restart</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="128"/>
        <source>Refresh</source>
        <translation>Aktualisieren</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="69"/>
        <source>Force end application</source>
        <translation>Beenden des Programms erzwingen</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="54"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="63"/>
        <source>Processes</source>
        <translation>Prozesse</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <source>Services</source>
        <translation>Dienste</translation>
    </message>
</context>
</TS>
